@@ -336,6 +336,21 @@ dataframes_graph <- function(
   )
 }
 
+#' @title Deprecated.
+#' @description Deprecated on 2018-10-24.
+#' @export
+#' @keywords internal
+#' @return Evaluated code.
+#' @param code Placeholder for the code to build a target/import.
+default_hook <- function(code){
+  .Deprecated(
+    "default_hook",
+    package = "drake",
+    msg = "default_hook() is deprecated."
+  )
+  force(code)
+}
+
 #' @title Deprecated function `default_system2_args`
 #' @description Use [default_Makefile_args()] instead.
 #' @details Deprecated on 2017-10.
@@ -492,6 +507,21 @@ drake_batchtools_tmpl_file <- function(
   drake_hpc_template_file(file = example, to = to, overwrite = overwrite)
 }
 
+#' @title Deprecated.
+#' @description Deprecated on 2018-10-24.
+#' @export
+#' @keywords internal
+#' @return Evaluated code.
+#' @param code Placeholder for the code to build a target/import.
+empty_hook <- function(code){
+  .Deprecated(
+    "empty_hook",
+    package = "drake",
+    msg = "empty_hook() is deprecated."
+  )
+  invisible()
+}
+
 #' @title Deprecated function `evaluate`
 #' @description Use [evaluate_plan()] instead.
 #' @details Deprecated on 2017-11-12.
@@ -726,7 +756,7 @@ load_basic_example <- function(
 }
 
 #' @title Deprecated function
-#' @description Do not use this function. `Drake`'s parallel algorithm
+#' @description Do not use this function. `drake`'s parallel algorithm
 #'   has changed since version 5.1.2, so `max_useful_jobs()`
 #'   will give you the wrong idea of how many jobs to use. Instead,
 #'   use the [predict_runtime()] function with a sensible value
@@ -759,7 +789,7 @@ max_useful_jobs <- function(
     package = "drake",
     msg = c(
       "Do not use max_useful_jobs(). ",
-      "Drake's parallel scheduling algorithm has changed, ",
+      "drake's parallel scheduling algorithm has changed, ",
       "so max_useful_jobs() will give you the wrong idea about ",
       "how many jobs to assign to `make()`. For a better estimate, ",
       "play around with predict_runtime() with sensible values, ",
@@ -787,6 +817,27 @@ max_useful_jobs <- function(
   # nocov end
 }
 
+#' @title Deprecated.
+#' @description Deprecated on 2018-10-24.
+#' @export
+#' @keywords internal
+#' @return Evaluated code.
+#' @param code Placeholder for the code to build a target/import.
+message_sink_hook <- function(code){
+  .Deprecated(
+    "message_sink_hook",
+    package = "drake",
+    msg = "message_sink_hook() is deprecated."
+  )
+  message <- file(paste0("message", Sys.getpid(), ".txt"), "w")
+  on.exit({
+    suppressWarnings(sink(type = "message"))
+    close(message)
+  })
+  sink(message, type = "message")
+  code
+}
+
 #' @title Deprecated: reconfigure an old project (built with drake <= 4.4.0)
 #'   to be compatible with later versions of drake.
 #' @export
@@ -813,7 +864,25 @@ migrate_drake_project <- function(
     )
   )
 }
-  
+
+#' @title Deprecated.
+#' @description Deprecated on 2018-10-24.
+#' @export
+#' @keywords internal
+#' @return Evaluated code.
+#' @param code Placeholder for the code to build a target/import.
+output_sink_hook <- function(code){
+  .Deprecated(
+    "output_sink_hook",
+    package = "drake",
+    msg = "output_sink_hook() is deprecated."
+  )
+  output <- paste0("output", Sys.getpid(), ".txt")
+  on.exit(suppressWarnings(sink(type = "output")))
+  sink(output, type = "output")
+  code
+}
+
 #' @title Deprecated function `plan`
 #' @description Use [drake_plan()] instead.
 #' @details Deprecated on 2017-10.
@@ -1381,7 +1450,7 @@ session <- function(
 #' @title Defunct function
 #' @description Staged parallelism is removed from drake,
 #' so this function is moot.
-#' Drake uses a much better parallel algorithm now.
+#' drake uses a much better parallel algorithm now.
 #' @details Made defunct on May 4, 2018.
 #' @export
 #' @keywords internal
@@ -1404,7 +1473,26 @@ parallel_stages <- function(
     msg = c(
       "Staged parallelism is removed from drake, ",
       "so the parallel_stages() function is moot. ",
-      "Drake uses a much better parallel algorithm now."
+      "drake uses a much better parallel algorithm now."
+    )
+  )
+}
+
+#' @title Deprecated.
+#' @description Deprecated on 2018-10-24.
+#' @export
+#' @keywords internal
+#' @return Evaluated code.
+#' @param code Placeholder for the code to build a target/import.
+silencer_hook <- function(code){
+  .Deprecated(
+    "silencer_hook",
+    package = "drake",
+    msg = "silencer_hook() is deprecated."
+  )
+  output_sink_hook(
+    message_sink_hook(
+      code
     )
   )
 }
