@@ -3,9 +3,11 @@ run_future <- function(config){
   queue <- new_priority_queue(config = config)
   workers <- initialize_workers(config)
   # While any targets are queued or running...
+  i <- 1
   while (work_remains(queue = queue, workers = workers, config = config)){
     for (id in seq_along(workers)){
       if (is_idle(workers[[id]])){
+        i <- 1
         # Also calls decrease-key on the queue.
         workers[[id]] <- conclude_worker(
           worker = workers[[id]],
@@ -31,7 +33,8 @@ run_future <- function(config){
         )
       }
     }
-    Sys.sleep(mc_wait)
+    Sys.sleep(config$sleep(i))
+    i <- i + 1
   }
 }
 
@@ -46,14 +49,24 @@ run_future <- function(config){
 #' @param config [drake_config()] list
 #' @param protect Names of targets that still need their
 #' dependencies available in `config$envir`.
-drake_future_task <- function(target, meta, config){
-  do_prework(config = config, verbose_packages = FALSE)
-  if (config$caching == "worker"){
-    build_and_store(
-      target = target, meta = meta, config = config, announce = FALSE)
-  } else {
-    just_build(target = target, meta = meta, config = config)
+drake_future_task <- function(target, meta, config, protect){
+  if (identical(config$caching, "worker")){
+    prune_envir(targets = target, config = config, downstream = protect)
   }
+  do_prework(config = config, verbose_packages = FALSE)
+  build <- just_build(target = target, meta = meta, config = config)
+  if (identical(config$caching, "master")){
+    build$checksum <- mc_get_outfile_checksum(target, config)
+    return(build)
+  }
+  conclude_build(
+    target = build$target,
+    value = build$value,
+    meta = build$meta,
+    config = config
+  )
+  set_attempt_flag(key = build$target, config = config)
+  list(target = target, checksum = mc_get_checksum(target, config))
 }
 
 new_worker <- function(id, target, config, protect){
@@ -65,14 +78,21 @@ new_worker <- function(id, target, config, protect){
   )){
     return(empty_worker(target = target))
   }
-  prune_envir(targets = target, config = config, downstream = protect)
+  if (identical(config$caching, "master")){
+    prune_envir(targets = target, config = config, downstream = protect)
+  }
   meta$start <- proc.time()
   config$cache$flush_cache() # Less data to pass this way.
   DRAKE_GLOBALS__ <- NULL # Fixes warning about undefined globals.
   # Avoid potential name conflicts with other globals.
   # When we solve #296, the need for such a clumsy workaround
   # should go away.
-  globals <- future_globals(target = target, meta = meta, config = config)
+  globals <- future_globals(
+    target = target,
+    meta = meta,
+    config = config,
+    protect = protect
+  )
   evaluator <- drake_plan_override(
     target = target,
     field = "evaluator",
@@ -85,7 +105,8 @@ new_worker <- function(id, target, config, protect){
       expr = drake_future_task(
         target = DRAKE_GLOBALS__$target,
         meta = DRAKE_GLOBALS__$meta,
-        config = DRAKE_GLOBALS__$config
+        config = DRAKE_GLOBALS__$config,
+        protect = DRAKE_GLOBALS__$protect
       ),
       packages = "drake",
       globals = globals,
@@ -95,12 +116,13 @@ new_worker <- function(id, target, config, protect){
   )
 }
 
-future_globals <- function(target, meta, config){
+future_globals <- function(target, meta, config, protect){
   globals <- list(
     DRAKE_GLOBALS__ = list(
       target = target,
       meta = meta,
-      config = config
+      config = config,
+      protect = protect
     )
   )
   if (identical(config$envir, globalenv())){
@@ -206,11 +228,21 @@ conclude_worker <- function(worker, config, queue){
   if (is_empty_worker(worker)){
     return(out)
   }
-  set_attempt_flag(key = "_attempt", config = config)
   build <- resolve_worker_value(worker = worker, config = config)
-  if (config$caching == "worker"){
+  if (identical(config$caching, "worker")){
+    mc_wait_checksum(
+      target = build$target,
+      checksum = build$checksum,
+      config = config
+    )
     return(out)
   }
+  set_attempt_flag(key = build$target, config = config)
+  mc_wait_outfile_checksum(
+    target = build$target,
+    checksum = build$checksum,
+    config = config
+  )
   conclude_build(
     target = build$target,
     value = build$value,
