@@ -13,25 +13,30 @@ test_with_dir("clustermq parallelism", {
   jobs <- scenario$jobs # ignoring for now, using 2 jobs
   load_mtcars_example(envir = e)
   for (parallelism in c("clustermq", "clustermq_staged")){
-    make(
-      e$my_plan,
-      parallelism = parallelism,
-      jobs = jobs,
-      envir = e,
-      verbose = 4,
-      garbage_collection = TRUE
-    )
-    config <- drake_config(e$my_plan, envir = e)
-    expect_equal(outdated(config), character(0))
-    make(
-      e$my_plan,
-      parallelism = parallelism,
-      jobs = jobs,
-      envir = e,
-      verbose = 4
-    )
-    expect_equal(justbuilt(config), character(0))
-    clean(destroy = TRUE)
+    for (caching in c("master", "worker")){
+      config <- drake_config(e$my_plan, envir = e)
+      expect_equal(length(outdated(config)), nrow(config$plan))
+      make(
+        e$my_plan,
+        parallelism = parallelism,
+        jobs = jobs,
+        caching = caching,
+        envir = e,
+        verbose = 4,
+        garbage_collection = TRUE
+      )
+      expect_equal(outdated(config), character(0))
+      make(
+        e$my_plan,
+        parallelism = parallelism,
+        jobs = jobs,
+        caching = caching,
+        envir = e,
+        verbose = 4
+      )
+      expect_equal(justbuilt(config), character(0))
+      clean(destroy = TRUE)
+    }
   }
   if ("package:clustermq" %in% search()){
     eval(parse(text = "detach('package:clustermq', unload = TRUE)"))
