@@ -56,3 +56,15 @@ test_with_dir("changes to commands are handled well", {
     sort(c("drake_target_1", "final"))
   )
 })
+
+test_with_dir("add a new target", {
+  plan <- drake_plan(a = as.integer(sqrt(4)))
+  cache <- storr::storr_environment()
+  config <- make(plan, cache = cache, session_info = FALSE)
+  expect_equal(justbuilt(config), "a")
+  expect_equal(readd(a, cache = cache), 2L)
+  plan <- rbind(plan, drake_plan(b = as.integer(sqrt(16))))
+  config <- make(plan, cache = cache, session_info = FALSE)
+  expect_equal(justbuilt(config), "b")
+  expect_equal(readd(b, cache = cache), 4L)
+})
